function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = require('path');
var fs = require('fs');
var childProcess = _interopDefault(require('child_process'));

var slash = path => {
	const isExtendedLengthPath = /^\\\\\?\\/.test(path);
	const hasNonAscii = /[^\u0000-\u0080]+/.test(path); // eslint-disable-line no-control-regex

	if (isExtendedLengthPath || hasNonAscii) {
		return path;
	}

	return path.replace(/\\/g, '/');
};

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types

function stylesheet(path$1, fileObject) {
  const extension = path.extname(path$1);
  if ([".css"].indexOf(extension.toLowerCase()) === -1) return;
  const referer = fileObject.opts.filename;
  const file = path.resolve(path.dirname(referer), path$1);

  if (!fs.existsSync(file)) {
    throw new Error(`The css file "${file}" does not exist.`);
  }

  try {
    return childProcess.execSync(`npx -f -q postcss "${slash(file)}" --use postcss-import autoprefixer cssnano --no-map`).toString();
  } catch (e) {
    throw new Error(`The css file "${file}" could not parsed.`);
  }
}

function plugin ({
  types: t
}) {
  return {
    name: "css inline",
    visitor: {
      ImportDeclaration(path, pass) {
        if (path.node.specifiers.length !== 1 || path.node.specifiers[0].type !== "ImportDefaultSpecifier") {
          return;
        }

        const styles = stylesheet(path.node.source.value, pass.file);
        if (typeof styles !== "string") return;
        const variableDeclaration = t.variableDeclaration("const", [t.variableDeclarator(path.node.specifiers[0].local, t.stringLiteral(styles))]);
        path.replaceWith(variableDeclaration);
      }

    }
  };
}

module.exports = plugin;
//# sourceMappingURL=plugin.js.map
